package com.liquidnet.service.adam.dto;

import com.liquidnet.commons.lang.constant.LnsRegex;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.Pattern;
import javax.validation.constraints.Size;
import java.io.Serializable;

@ApiModel(value = "AdamThirdPartParam", description = "第三方账号登录注册入参")
public class AdamThirdPartParam implements Serializable {
    private static final long serialVersionUID = 675588088506034208L;
    @ApiModelProperty(position = 11, required = true, value = "第三方账号唯一标识[64]")
//    @NotBlank(message = "OPENID不能为空")
    private String openId;
    @ApiModelProperty(position = 12, required = true, value = "昵称[64]", example = "Swagger")
    private String nickname;
    @ApiModelProperty(position = 13, required = true, value = "头像[255]", example = "http://pic.zhengzai.tv/default/avatar.png")
    @Size(max = 255, message = "已超出头像链接长度限制")
    private String avatar;
    @ApiModelProperty(position = 14, required = true, value = "平台类型[255]", allowableValues = "WEIBO,WECHAT,QQ")
    @Pattern(regexp = LnsRegex.Valid.TRIPLE_PF_FOR_ULGOIN, message = "平台类型无效")
    @NotBlank(message = "平台类型不能为空")
    private String platform;
    @ApiModelProperty(position = 15, required = false, value = "手机号[新账号时必传]")
    private String mobile;
    @ApiModelProperty(position = 16, required = false, value = "验证码[新账号时必传]")
    private String code;
    @ApiModelProperty(position = 17, required = true, value = "第三方应用标识[64]，WXS01-正在现场公众号｜WXS02-MDSK公众号｜WXM01-正在现场移动应用｜WXA01-正在现场小程序｜WXA02-草莓音乐节小程序｜WXA03-MDSK音乐节（适用于同一平台多个应用服务，例如微信的公众号、小程序等）")
    @Pattern(regexp = LnsRegex.Valid.TRIPLE_AT_FOR_ULGOIN, message = "平台应用类型无效")
    private String openType;
    @ApiModelProperty(position = 18, required = true, value = "第三方账号应用标识[64]，适用于同一平台多个应用服务（例如微信的openid对应接口属性openid、unionid对应接口属性openId）")
    private String openid;
//    @ApiModelProperty(position = 19, required = false, value = "强制绑定[第三方账号已绑定其他手机号时]", example = "false")
//    private Boolean force;

    public String getOpenType() {
        return openType;
    }

    public void setOpenType(String openType) {
        this.openType = openType;
    }

    public String getOpenid() {
        return openid;
    }

    public void setOpenid(String openid) {
        this.openid = openid;
    }

    public String getOpenId() {
        return openId;
    }

    public void setOpenId(String openId) {
        this.openId = openId;
    }

    public String getNickname() {
        return nickname;
    }

    public void setNickname(String nickname) {
        this.nickname = nickname;
    }

    public String getAvatar() {
        return avatar;
    }

    public void setAvatar(String avatar) {
        this.avatar = avatar;
    }

    public String getPlatform() {
        return platform;
    }

    public void setPlatform(String platform) {
        this.platform = platform;
    }

    public String getMobile() {
        return mobile;
    }

    public void setMobile(String mobile) {
        this.mobile = mobile;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
}
