package com.liquidnet.service.adam.service;

import com.liquidnet.service.adam.dto.AdamThirdPartParam;
import com.liquidnet.service.adam.dto.vo.AdamRealInfoVo;
import com.liquidnet.service.adam.dto.vo.AdamUserInfoVo;
import com.liquidnet.service.base.ResponseDto;

/**
 * <p>
 * 用户 服务类
 * </p>
 *
 * @author liquidnet
 * @since 2021-05-10
 */
public interface IAdamUserService {

    /**
     * 手机号注册
     *
     * @param mobile
     * @return AdamUserInfoVo
     */
    AdamUserInfoVo register(String mobile);

    /**
     * 第三方账号注册
     *
     * @param param
     * @return ResponseDto<AdamUserInfoVo>
     */
    ResponseDto<AdamUserInfoVo> register(AdamThirdPartParam param);
    /**
     * IOS端用户微信唯一标识处理（redis、mongo、mq）
     * 原对应关系
     * - 安卓端、IOS端：微信openid｜unionid～当前API接收参数openId
     * 接收参数新增openid字段后
     * - 安卓端、IOS端统一：微信unionid～当前API接收参数openId，微信openid～当前API接收参数openid
     *
     * @param param
     * @return ResponseDto<AdamUserInfoVo>
     */
    ResponseDto<AdamUserInfoVo> registerV1(AdamThirdPartParam param);

    /**
     * 第三方账号绑定（不存在已绑定账号）
     *
     * @param uid
     * @param param
     */
    void bindTpa(String uid, AdamThirdPartParam param);
    void bindTpaV1(String uid, AdamThirdPartParam param);

    /**
     * 第三方账号绑定（存在已绑定账号）
     *
     * @param bindUid
     * @param unBindUid
     * @param param
     */
    void bindTpaForce(String bindUid, String unBindUid, AdamThirdPartParam param);

    /**
     * 第三方账号解绑
     *
     * @param uid
     * @param platform
     */
    void unBindTpa(String uid, String platform);

    void close(String uid);

    AdamRealInfoVo identity(String uid, String name, String idCard);
}
